Method: Fixie::Model#instantiate_from_fixture
- Defined in:
- lib/fixie.rb
#instantiate_from_fixture(fixture) ⇒ Object
This method is used to get an instance of the model from a fixture hash. The default implementation is to just pass the hash to the model’s constructor.
167 168 169 |
# File 'lib/fixie.rb', line 167 def instantiate_from_fixture(fixture) new(fixture) end |